@@ -1,8 +1,9 @@
-from pyaliner.align import align, LEV, COMPACT, CLASSIC, GAP, JOIN, SKIP, Seq, as_cigar, compact, itp_align, tp1p2_align
+from pyaliner.align import align, LEV, COMPACT, CLASSIC, GAP, JOIN, SKIP, Seq, as_cigar, compact, itp_align, \
+    tp1p2_align, three_way_realign
 from pyaliner.compare import compare_in_true_pred_from_file, compare_true_pred_from_file, compare_in_true_pred, \
     compare_true_pred, compare_in_true_pred_from_files, compare_true_pred_from_files
 from pyaliner.display import in_terminal, rich_paired_in_true_pred, rich_paired_true_pred, rich_inlined_true_pred, \
-    seq_true_pred_paired, seq_in_true_pred_paired
+    seq_true_pred_paired, seq_in_true_pred_paired, seq_true_pred1_pred2, rich_paired_true_pred1_pred2
 
 __all__ = ['align',
            'LEV',
@@ -16,6 +17,7 @@ __all__ = ['align',
            'compact',
            'itp_align',
            'tp1p2_align',
+           'three_way_realign',
            'compare_in_true_pred_from_file',
            'compare_in_true_pred_from_files',
            'compare_true_pred_from_file',
@@ -26,5 +28,7 @@ __all__ = ['align',
            'rich_paired_in_true_pred',
            'rich_paired_true_pred',
            'rich_inlined_true_pred',
+           'rich_paired_true_pred1_pred2',
+           'seq_in_true_pred_paired',
            'seq_true_pred_paired',
-           'seq_in_true_pred_paired']
+           'seq_true_pred1_pred2']
